package com.bonus.material.scrap.mapper;

import java.util.List;

import com.bonus.material.repair.domain.RepairAuditDetails;
import com.bonus.material.repair.domain.RepairRecord;
import com.bonus.material.scrap.domain.ScrapApplyDetails;

/**
 * 报废任务详细Mapper接口
 * 
 * @author xsheng
 * @date 2024-10-16
 */
public interface ScrapApplyDetailsMapper {
    /**
     * 查询报废任务详细
     * 
     * @param id 报废任务详细主键
     * @return 报废任务详细
     */
    public ScrapApplyDetails selectScrapApplyDetailsById(Long id);

    /**
     * 查询报废任务详细列表
     * 
     * @param scrapApplyDetails 报废任务详细
     * @return 报废任务详细集合
     */
    public List<ScrapApplyDetails> selectScrapApplyDetailsList(ScrapApplyDetails scrapApplyDetails);

    /**
     * 新增报废任务详细
     * 
     * @param scrapApplyDetails 报废任务详细
     * @return 结果
     */
    public int insertScrapApplyDetails(ScrapApplyDetails scrapApplyDetails);

    /**
     * 修改报废任务详细
     * 
     * @param scrapApplyDetails 报废任务详细
     * @return 结果
     */
    public int updateScrapApplyDetails(ScrapApplyDetails scrapApplyDetails);

    /**
     * 删除报废任务详细
     * 
     * @param id 报废任务详细主键
     * @return 结果
     */
    public int deleteScrapApplyDetailsById(Long id);

    /**
     * 批量删除报废任务详细
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteScrapApplyDetailsByIds(Long[] ids);

    RepairAuditDetails getByRepairId(String s);

    List<RepairRecord> getGyoupRepairRecord(RepairAuditDetails byRepairId);
}
