package com.bonus.material.scrap.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.scrap.domain.ScrapApplyDetails;
import com.bonus.material.scrap.service.IScrapApplyDetailsService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 报废任务详细Controller
 * 
 * @author xsheng
 * @date 2024-10-16
 */
@Api(tags = "报废任务详细接口")
@RestController
@RequestMapping("/scrap_apply_details")
public class ScrapApplyDetailsController extends BaseController {
    @Autowired
    private IScrapApplyDetailsService scrapApplyDetailsService;

    /**
     * 查询报废任务详细列表
     */
    @ApiOperation(value = "查询报废任务详细列表")
    @RequiresPermissions("scrap:details:list")
    @GetMapping("/list")
    public TableDataInfo list(ScrapApplyDetails scrapApplyDetails) {
        startPage();
        List<ScrapApplyDetails> list = scrapApplyDetailsService.selectScrapApplyDetailsList(scrapApplyDetails);
        return getDataTable(list);
    }

    /**
     * 导出报废任务详细列表
     */
    @ApiOperation(value = "导出报废任务详细列表")
    @PreventRepeatSubmit
    @RequiresPermissions("scrap:details:export")
    @SysLog(title = "报废任务详细", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出报废任务详细")
    @PostMapping("/export")
    public void export(HttpServletResponse response, ScrapApplyDetails scrapApplyDetails) {
        List<ScrapApplyDetails> list = scrapApplyDetailsService.selectScrapApplyDetailsList(scrapApplyDetails);
        ExcelUtil<ScrapApplyDetails> util = new ExcelUtil<ScrapApplyDetails>(ScrapApplyDetails.class);
        util.exportExcel(response, list, "报废任务详细数据");
    }

    /**
     * 获取报废任务详细详细信息
     */
    @ApiOperation(value = "获取报废任务详细详细信息")
    @RequiresPermissions("scrap:details:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(scrapApplyDetailsService.selectScrapApplyDetailsById(id));
    }

    /**
     * 新增报废任务详细
     */
    @ApiOperation(value = "新增报废任务详细")
    @PreventRepeatSubmit
    @RequiresPermissions("scrap:details:add")
    @SysLog(title = "报废任务详细", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增报废任务详细")
    @PostMapping
    public AjaxResult add(@RequestBody ScrapApplyDetails scrapApplyDetails) {
        try {
            return toAjax(scrapApplyDetailsService.insertScrapApplyDetails(scrapApplyDetails));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改报废任务详细
     */
    @ApiOperation(value = "修改报废任务详细")
    @PreventRepeatSubmit
    @RequiresPermissions("scrap:details:edit")
    @SysLog(title = "报废任务详细", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改报废任务详细")
    @PutMapping
    public AjaxResult edit(@RequestBody ScrapApplyDetails scrapApplyDetails) {
        try {
            return toAjax(scrapApplyDetailsService.updateScrapApplyDetails(scrapApplyDetails));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除报废任务详细
     */
    @ApiOperation(value = "删除报废任务详细")
    @PreventRepeatSubmit
    @RequiresPermissions("scrap:details:remove")
    @SysLog(title = "报废任务详细", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除报废任务详细")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(scrapApplyDetailsService.deleteScrapApplyDetailsByIds(ids));
    }
}
